#undef ENABLE_NLS
#undef HAVE_GETTEXT
#undef HAVE_CATGETS
#undef HAVE_DLADDR
#undef HAVE_GET_TEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_XKB
